<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class InsumoFactory {
    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function getInsumos() {
        $sql = "SELECT FCM_INSUMO.NRINSUMO, FCM_INSUMO.NMINSUMO, FCM_INSUMO.CDINSUMO,FCM_UNIDADEMEDIDA.NMUNIDADEMEDIDA, FCM_UNIDADEMEDIDA.NMABREVUNIDADEMEDIDA,
                       FCM_UNIDADEMEDIDA.NRUNIDADEMEDIDA, FCM_INSUMO.CDPRODUTO,
                    CASE WHEN FCM_INSUMO.QTESTOQUE IS NULL THEN 0 ELSE FCM_INSUMO.QTESTOQUE END AS QTESTOQUE,
                    CASE WHEN FCM_INSUMO.QTULTIMARETIRADA IS NULL THEN 0 ELSE FCM_INSUMO.QTULTIMARETIRADA END AS QTULTIMARETIRADA
                FROM FCM_INSUMO
                JOIN FCM_UNIDADEMEDIDA
                  ON FCM_INSUMO.NRUNIDADEMEDIDA = FCM_UNIDADEMEDIDA.NRUNIDADEMEDIDA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertInsumo($parametros) {
		$sql = "INSERT INTO FCM_INSUMO (
					NRINSUMO,           NMINSUMO,       CDINSUMO,   CDPRODUTO,
					NRUNIDADEMEDIDA,    NRORG,			IDATIVO,	DTINCLUSAO,
					CDOPERINCLUSAO,		NRORGINCLUSAO	
				)
				VALUES (
					:NRINSUMO,		    :NMINSUMO,      :CDINSUMO,  :CDPRODUTO,
					:NRUNIDADEMEDIDA,	:NRORG,			'S',		SYSDATE,
					:CDOPERINCLUSAO,	:NRORGINCLUSAO
				)";

		$this->connection->executeStatement($sql, $parametros);
	}

    public function updateInsumo($parametros) {
        $sql = "UPDATE FCM_INSUMO
                SET NMINSUMO        = :NMINSUMO,
                    CDINSUMO        = :CDINSUMO,
                    CDPRODUTO       = :CDPRODUTO,
                    NRUNIDADEMEDIDA = :NRUNIDADEMEDIDA,
                    CDOPERULTATU    = :CDOPERULTATU,
                    NRORGULTATU     = :NRORGULTATU
                WHERE NRINSUMO = :NRINSUMO";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function deleteInsumos($parametros) {
        $sql = "DELETE
                FROM FCM_INSUMO
                WHERE NRINSUMO IN (".$parametros.")";
        
        $this->connection->executeStatement($sql);
    }

    public function getUniMedida() {
        $sql = "SELECT NRUNIDADEMEDIDA, NMUNIDADEMEDIDA
                FROM FCM_UNIDADEMEDIDA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertImgInsumo($param){
        $sql = "INSERT INTO FCM_IMGINSUMO (NRIMGINSUMO, NRINSUMO, DSCAMINHO, NRORG, IDATIVO, DSTYPE, NRSIZE)
                VALUES (:NRIMGINSUMO, :NRINSUMO, :DSCAMINHO, :NRORG, 'S', :DSTYPE, :NRSIZE)";
        
        $this->connection->executeStatement($sql, $param);
    }

    public function getFotosInsumo($parametros) {
		$sql = "SELECT NRIMGINSUMO, DSCAMINHO
				FROM FCM_IMGINSUMO
				WHERE NRINSUMO = :NRINSUMO";

		return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
	}

	public function deleteFotoInsumo($parametros) {
		$sql = "DELETE
				FROM FCM_IMGINSUMO
				WHERE NRIMGINSUMO = :NRIMGINSUMO";
		
		$this->connection->executeStatement($sql, $parametros);
	}
}

?>