<?php

namespace FM\Service;

use FM\Factory\CategoriaManutFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CategoriaManutService {

    protected $CategoriaManutFactory;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, CategoriaManutFactory $CategoriaManutFactory, Environment $Environment, NewCode $newCode) {
        $this->CategoriaManutFactory = $CategoriaManutFactory;
        $this->connection            = $entityManager->getConnection();
        $this->Environment           = $Environment;
        $this->newCode               = $newCode;
    }

    public function insertNovaCategoriaManutencao($parametros) {
        $NRORG = 20;
        $this->connection->beginTransaction();

        try {

            $NRCATEGORIAMANUT = $this->newCode->getCodeByTableName("FCM_CATEGORIAMANUT", $NRORG, 1, 10, true);

            $parametrosCategoria = array(
                "NRCATEGORIAMANUT"  => $NRCATEGORIAMANUT,
                "NMCATEGORIAMANUT"  => $parametros['NMCATEGORIA'],
                "NMABREVCATEGMANUT" => $parametros['NMABREVIATURA'],
                "NRORG"             => $NRORG
            );

            $this->CategoriaManutFactory->insertNovaCategoriaManutencao($parametrosCategoria);

            forEach($parametros['TECNICOSREGISTRADOS'] as $Funcionario) {

                $NRFUNCCATEGORIAMANUT = $this->newCode->getCodeByTableName("FCM_FUNCCATEGORIAMANUT", $NRORG, 1, 10, true);

                $parametrosFuncionarios = array(
                    "NRFUNCCATEGORIAMANUT" => $NRFUNCCATEGORIAMANUT,
                    "NRCATEGORIAMANUT"     => $NRCATEGORIAMANUT,
                    "NRFUNCIONARIO"        => $Funcionario,
                    "NRORG"                => $NRORG
                );
                $this->CategoriaManutFactory->insertFuncionarioCategoriaManut($parametrosFuncionarios);
            }

            $this->connection->commit();
            $response = 'OK';

      } catch(\Exception $e) {
          $this->connection->rollback();
          $response = ($e->getMessage());
      }
       return $response;
    }

    public function saveCategoriaManutencao($params) {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();

            foreach ($params["ROWS"] as $row) {
                if ($row["NRCATEGORIAMANUT"] == 0) {
                    $NRCATEGORIAMANUT = $this->newCode->getCodeByTableName("FCM_CATEGORIAMANUT", $nrorg, 1, 10, true);
    
                    $parametrosCategoria = array(
                        "NRCATEGORIAMANUT"  => $NRCATEGORIAMANUT,
                        "NMCATEGORIAMANUT"  => $row['NMCATEGORIAMANUT'],
                        "NMABREVCATEGMANUT" => $row['NMABREVCATEGMANUT'],
                        "NRORG"             => $nrorg,
                        "CDOPERINCLUSAO"    => $operador,
                        "NRORGINCLUSAO"     => $nrorg,
                        "CDOPERULTATU"      => $operador,
                        "NRORGULTATU"       => $nrorg          
                    );

                    $this->CategoriaManutFactory->insertCategoriaManutencao($parametrosCategoria);
                } else {
                    $parametrosCategoria = array(
                        "NRCATEGORIAMANUT"  => $row['NRCATEGORIAMANUT'],
                        "NMCATEGORIAMANUT"  => $row['NMCATEGORIAMANUT'],
                        "NMABREVCATEGMANUT" => $row['NMABREVCATEGMANUT'],
                        "CDOPERULTATU"      => $operador,
                        "NRORGULTATU"       => $nrorg          
                    );

                    $this->CategoriaManutFactory->editCategoriaManutencao($parametrosCategoria);
                }
            }

            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function getCategoriasManutencao() {
        $data = $this->CategoriaManutFactory->getCategoriasManutencao();

        foreach ($data['data'] as &$row) {
            $row['NRFUNCIONARIO'] = explode(', ', $row['NRFUNCIONARIO']);
        }

        return $data;
    }

    public function getTecnicosRegistrados() {
        return $this->CategoriaManutFactory->getTecnicosRegistrados();
    }

    public function deleteCategoriasManutencao($params) {
        $parametro = implode(',', $params["NRS"]);
        $this->CategoriaManutFactory->deleteCategoriasManutencao($parametro);
    }
}

?>