<?php

namespace FM\Service;

use FM\Factory\SolicitacaoServFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use FM\Factory\ComentSolicitServFactory;
use Doctrine\ORM\EntityManager;
use FM\Service\FileServerService;

class SolicitacaoServService {

    protected $SolicitacaoServFactory;
    protected $Environment;
    protected $newCode;
    protected $ComentSolicitServFactory;
    protected $connection;
    protected $FileServerService;
    protected $fileServerUrl;

    public function __construct (SolicitacaoServFactory $SolicitacaoServFactory, Environment $Environment, NewCode $newCode, ComentSolicitServFactory $ComentSolicitServFactory, EntityManager $entityManager, FileServerService $FileServerService, $fileServerUrl) {
        $this->SolicitacaoServFactory = $SolicitacaoServFactory;
        $this->Environment = $Environment;
        $this->newCode = $newCode;
        $this->ComentSolicitServFactory = $ComentSolicitServFactory;
        $this->connection = $entityManager->getConnection();
        $this->FileServerService = $FileServerService;
        $this->fileServerUrl = $fileServerUrl;
    }

    public function getSolicitacoesServicos() {
        return $this->SolicitacaoServFactory->getSolicitacoesServicos();
    }

    public function saveRecusarSolicitacoes($parametros) {
        try {
            foreach ($parametros["ROWS"] as $row) {
                $this->recusarSolicitacao($row);
                $row["DSCOMENTARIO"] = $parametros["DSCOMENTARIO"];
                $this->insertComentarioSolicitacao($row);
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function recusarSolicitacao($parametros) {
        $this->connection->beginTransaction();

        try {
            $parametroRecusar = array(
                "NRSOLICITACAOSERV" => $parametros["NRSOLICITACAOSERV"]
            );

            $this->SolicitacaoServFactory->recusarSolicitacao($parametroRecusar);

            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function insertComentarioSolicitacao($parametros) {
        $this->connection->beginTransaction();

        try {
            $cdOperador = $this->Environment->getCdOperador();
            $nrorg = $this->Environment->getNrorg();
            $NRCOMENTSOLICITSERV = $this->newCode->getCodeByTableName("FCM_COMENTSOLICITSERV", 20, 1, 10, true);

            $parametroComentario = array(
                "NRCOMENTSOLICITSERV"   => $NRCOMENTSOLICITSERV,
                "NRSOLICITACAOSERV"     => $parametros["NRSOLICITACAOSERV"],
                "DSCOMENTARIO"          => $parametros["DSCOMENTARIO"],
                "NRORG"                 => $nrorg,
                "CDOPERINCLUSAO"        => $cdOperador,
                "NRORGINCLUSAO"         => $nrorg,
                "CDOPERULTATU"          => $cdOperador,
                "NRORGULTATU"           => $nrorg
            );

            $this->SolicitacaoServFactory->insertComentarioSolicitacao($parametroComentario);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function saveSolicitacaoServico($parametros) {
        $this->connection->beginTransaction();

        try {
            $cdOperador = $this->Environment->getCdOperador();
            $nrorg = $this->Environment->getNrorg();

            $NRSOLICITACAOSERV = $this->newCode->getCodeByTableName("FCM_SOLICITACAOSERV", 20, 1, 10, true);
            $parametroSolicitacao = array(
                "NRSOLICITACAOSERV" => $NRSOLICITACAOSERV,
                "NREQUIPAMENTO"     => $parametros["NREQUIPAMENTO"],
                "NRCATEGORIAMANUT"  => $parametros["NRCATEGORIAMANUT"],
                "NRIMPACTOMANUT"    => $parametros["NRIMPACTOMANUT"],
                "DSSOLICITACAOSERV" => $parametros["DSSOLICITACAOSERV"],
                "NRORG"             => $nrorg,
                "CDOPERINCLUSAO"    => $cdOperador,
                "NRORGINCLUSAO"     => $nrorg,
                "CDOPERULTATU"      => $cdOperador,
                "NRORGULTATU"       => $nrorg,
                "NMSOLICITACAOSERV" => $parametros["NMSOLICITACAOSERV"]
            );

            $this->SolicitacaoServFactory->saveSolicitacaoServico($parametroSolicitacao);

            $parametroFoto = array(
                "NRSOLICITACAOSERV" => $NRSOLICITACAOSERV,
                "FOTOS"             => $parametros["FOTOS"]
            );

            $this->insertFotosSolicitacao($parametroFoto);

            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function insertFotosSolicitacao($parametros) {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrorg();

            foreach ($parametros["FOTOS"] as $foto) {
                $img = $this->FileServerService->uploadFoto($foto, "foto_vistoria_fm");

                $NRIMGSOLICITACAOSERV = $this->newCode->getCodeByTableName('FCM_IMGSOLICITACAOSERV', 20, 1, 10, true);
                $parametroFoto = array(
                    "NRIMGSOLICITACAOSERV"  => $NRIMGSOLICITACAOSERV,
                    "NRSOLICITACAOSERV"     => $parametros["NRSOLICITACAOSERV"],
                    "DSCAMINHO"             => $this->fileServerUrl . "/files/" . $img["path"],
                    "NRORG"                 => $nrorg,
                    "DSTYPE"                => $img["type"],
                    "NRSIZE"                => $img["size"]
                );

                $this->SolicitacaoServFactory->insertFotoSolicitacao($parametroFoto);
            }

            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollback();
        }
    }

    public function getImpactoManut() {
        return $this->SolicitacaoServFactory->getImpactoManut();
    }

    public function getPrioridadesManut() {
        return $this->SolicitacaoServFactory->getPrioridadesManut();
    }

    public function getFotosSolicitacao($parametros) {
        $parametroFoto = array(
            "NRSOLICITACAOSERV" => $parametros["NRSOLICITACAOSERV"]
        );

        return $this->SolicitacaoServFactory->getFotosSolicitacao($parametroFoto);
    }

    public function getComentariosSolicitacao($parametros) {
        $parametroFoto = array(
            "NRSOLICITACAOSERV" => $parametros["NRSOLICITACAOSERV"]
        );

        return $this->SolicitacaoServFactory->getComentariosSolicitacao($parametroFoto);
    }

    public function getOperadorLogado() {
        return array(
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );
    }

    public function getOperadores() {
        return $this->SolicitacaoServFactory->getOperadores();
    }

    public function getFuncionarios() {
        return $this->SolicitacaoServFactory->getFuncionarios();
    }

    public function getFuncionarioLogado() {
        $parametroFuncionario = array(
            $CDOPERADOR = $this->Environment->getCdOperador()
        );

        return $this->SolicitacaoServFactory->getFuncionarioLogado($parametroFuncionario);
    }
    
    public function listSolicitacaoServ($params) {
        $solicitacoes = $this->SolicitacaoServFactory->listSolicitacaoServ($params);
        return $solicitacoes;
    }
    
    public function listSolicitacaoServJoin($params) {
        $solicitacoes = $this->SolicitacaoServFactory->listSolicitacaoServJoin($params);
        return $solicitacoes;
    }
    
    public function mudarStatus($param) {
        $this->connection->beginTransaction();
        
        try {
            $this->SolicitacaoServFactory->mudarStatus(array("NRSOLICITACAOSERV" => intval($param['NRSOLICITACAOSERV'])));
            
            $this->ComentSolicitServFactory->postComentarios(array(
            "NRCOMENTSOLICITSERV" => $this->newCode->getCodeByTableName("FCM_COMENTSOLICITSERV", 20, 1, 10, true),
            "NRSOLICITACAOSERV" => intval($param['NRSOLICITACAOSERV']),
            "NRFUNCCOMENTARIO" => intval($param['NRFUNCCOMENTARIO']),
            "DTCOMENTARIO" => $param['DTCOMENTARIO'],
            "DSCOMENTARIO" => $param['DSCOMENTARIO'],
            "NRORG" => 20 
        ));
            
            $this->connection->commit();
            $response = "OK";
        } catch(\Exception $e) {
            $this->connection->rollback();
            $response = ($e->getMessage());
        }
        return [$response];
    }
}

?>